@@ -13,16 +13,18 @@ Usage::
     client: AccountClient = session.client("account")
     ```
 """
-from typing import Any, Dict, Mapping, Type
+from typing import Any, Dict, Mapping, Sequence, Type
 
 from botocore.client import BaseClient, ClientMeta
 
-from .literals import AlternateContactTypeType
+from .literals import AlternateContactTypeType, RegionOptStatusType
 from .type_defs import (
     ContactInformationTypeDef,
     EmptyResponseMetadataTypeDef,
     GetAlternateContactResponseTypeDef,
     GetContactInformationResponseTypeDef,
+    GetRegionOptStatusResponseTypeDef,
+    ListRegionsResponseTypeDef,
 )
 
 __all__ = ("AccountClient",)
@@ -39,6 +41,7 @@ class BotocoreClientError(BaseException):
 class Exceptions:
     AccessDeniedException: Type[BotocoreClientError]
     ClientError: Type[BotocoreClientError]
+    ConflictException: Type[BotocoreClientError]
     InternalServerException: Type[BotocoreClientError]
     ResourceNotFoundException: Type[BotocoreClientError]
     TooManyRequestsException: Type[BotocoreClientError]
@@ -88,6 +91,26 @@ class AccountClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_account/client/#delete_alternate_contact)
         """
 
+    def disable_region(
+        self, *, RegionName: str, AccountId: str = ...
+    ) -> EmptyResponseMetadataTypeDef:
+        """
+        Disables (opts-out) a particular Region for an account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/account.html#Account.Client.disable_region)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_account/client/#disable_region)
+        """
+
+    def enable_region(
+        self, *, RegionName: str, AccountId: str = ...
+    ) -> EmptyResponseMetadataTypeDef:
+        """
+        Enables (opts-in) a particular Region for an account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/account.html#Account.Client.enable_region)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_account/client/#enable_region)
+        """
+
     def generate_presigned_url(
         self,
         ClientMethod: str,
@@ -123,6 +146,31 @@ class AccountClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_account/client/#get_contact_information)
         """
 
+    def get_region_opt_status(
+        self, *, RegionName: str, AccountId: str = ...
+    ) -> GetRegionOptStatusResponseTypeDef:
+        """
+        Retrieves the opt-in status of a particular Region.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/account.html#Account.Client.get_region_opt_status)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_account/client/#get_region_opt_status)
+        """
+
+    def list_regions(
+        self,
+        *,
+        AccountId: str = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...,
+        RegionOptStatusContains: Sequence[RegionOptStatusType] = ...
+    ) -> ListRegionsResponseTypeDef:
+        """
+        Lists all the Regions for a given account and their respective opt-in statuses.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/account.html#Account.Client.list_regions)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_account/client/#list_regions)
+        """
+
     def put_alternate_contact(
         self,
         *,
