@@ -12,9 +12,9 @@ Usage::
     ```
 """
 import sys
-from typing import Dict
+from typing import Dict, List, Sequence
 
-from .literals import AlternateContactTypeType
+from .literals import AlternateContactTypeType, RegionOptStatusType
 
 if sys.version_info >= (3, 9):
     from typing import TypedDict
@@ -26,14 +26,21 @@ __all__ = (
     "AlternateContactTypeDef",
     "ContactInformationTypeDef",
     "DeleteAlternateContactRequestRequestTypeDef",
+    "DisableRegionRequestRequestTypeDef",
     "ResponseMetadataTypeDef",
+    "EnableRegionRequestRequestTypeDef",
     "GetAlternateContactRequestRequestTypeDef",
     "GetContactInformationRequestRequestTypeDef",
+    "GetRegionOptStatusRequestRequestTypeDef",
+    "ListRegionsRequestRequestTypeDef",
+    "RegionTypeDef",
     "PutAlternateContactRequestRequestTypeDef",
     "PutContactInformationRequestRequestTypeDef",
     "EmptyResponseMetadataTypeDef",
     "GetAlternateContactResponseTypeDef",
     "GetContactInformationResponseTypeDef",
+    "GetRegionOptStatusResponseTypeDef",
+    "ListRegionsResponseTypeDef",
 )
 
 AlternateContactTypeDef = TypedDict(
@@ -101,6 +108,27 @@ class DeleteAlternateContactRequestRequestTypeDef(
     pass
 
 
+_RequiredDisableRegionRequestRequestTypeDef = TypedDict(
+    "_RequiredDisableRegionRequestRequestTypeDef",
+    {
+        "RegionName": str,
+    },
+)
+_OptionalDisableRegionRequestRequestTypeDef = TypedDict(
+    "_OptionalDisableRegionRequestRequestTypeDef",
+    {
+        "AccountId": str,
+    },
+    total=False,
+)
+
+
+class DisableRegionRequestRequestTypeDef(
+    _RequiredDisableRegionRequestRequestTypeDef, _OptionalDisableRegionRequestRequestTypeDef
+):
+    pass
+
+
 ResponseMetadataTypeDef = TypedDict(
     "ResponseMetadataTypeDef",
     {
@@ -112,6 +140,27 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
+_RequiredEnableRegionRequestRequestTypeDef = TypedDict(
+    "_RequiredEnableRegionRequestRequestTypeDef",
+    {
+        "RegionName": str,
+    },
+)
+_OptionalEnableRegionRequestRequestTypeDef = TypedDict(
+    "_OptionalEnableRegionRequestRequestTypeDef",
+    {
+        "AccountId": str,
+    },
+    total=False,
+)
+
+
+class EnableRegionRequestRequestTypeDef(
+    _RequiredEnableRegionRequestRequestTypeDef, _OptionalEnableRegionRequestRequestTypeDef
+):
+    pass
+
+
 _RequiredGetAlternateContactRequestRequestTypeDef = TypedDict(
     "_RequiredGetAlternateContactRequestRequestTypeDef",
     {
@@ -142,6 +191,48 @@ GetContactInformationRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredGetRegionOptStatusRequestRequestTypeDef = TypedDict(
+    "_RequiredGetRegionOptStatusRequestRequestTypeDef",
+    {
+        "RegionName": str,
+    },
+)
+_OptionalGetRegionOptStatusRequestRequestTypeDef = TypedDict(
+    "_OptionalGetRegionOptStatusRequestRequestTypeDef",
+    {
+        "AccountId": str,
+    },
+    total=False,
+)
+
+
+class GetRegionOptStatusRequestRequestTypeDef(
+    _RequiredGetRegionOptStatusRequestRequestTypeDef,
+    _OptionalGetRegionOptStatusRequestRequestTypeDef,
+):
+    pass
+
+
+ListRegionsRequestRequestTypeDef = TypedDict(
+    "ListRegionsRequestRequestTypeDef",
+    {
+        "AccountId": str,
+        "MaxResults": int,
+        "NextToken": str,
+        "RegionOptStatusContains": Sequence[RegionOptStatusType],
+    },
+    total=False,
+)
+
+RegionTypeDef = TypedDict(
+    "RegionTypeDef",
+    {
+        "RegionName": str,
+        "RegionOptStatus": RegionOptStatusType,
+    },
+    total=False,
+)
+
 _RequiredPutAlternateContactRequestRequestTypeDef = TypedDict(
     "_RequiredPutAlternateContactRequestRequestTypeDef",
     {
@@ -212,3 +303,21 @@ GetContactInformationResponseTypeDef = TypedDict(
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
+
+GetRegionOptStatusResponseTypeDef = TypedDict(
+    "GetRegionOptStatusResponseTypeDef",
+    {
+        "RegionName": str,
+        "RegionOptStatus": RegionOptStatusType,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListRegionsResponseTypeDef = TypedDict(
+    "ListRegionsResponseTypeDef",
+    {
+        "NextToken": str,
+        "Regions": List[RegionTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
